@@ -88,7 +88,6 @@ class PersistentTaskGroup:
     ) -> "asyncio.Task":
         if not self._entered:
             # When used as object attribute, auto-enter.
-            self._current_taskgroup_token = current_ptaskgroup.set(self)
             self._entered = True
         if self._exiting and self._unfinished_tasks == 0:
             raise RuntimeError(f"{self!r} has already finished")
@@ -128,9 +127,6 @@ class PersistentTaskGroup:
             self._on_completed_fut = None
 
         assert self._unfinished_tasks == 0
-        if self._current_taskgroup_token:
-            current_ptaskgroup.reset(self._current_taskgroup_token)
-        self._current_taskgroup_token = None
         self._on_completed_fut = None
         _all_ptaskgroups.discard(self)
         return propagate_cancellation_error
@@ -234,6 +230,9 @@ class PersistentTaskGroup:
         prop_ex = await self._wait_completion()
         if prop_ex is not None:
             propagate_cancellation_error = prop_ex
+        if self._current_taskgroup_token:
+            current_ptaskgroup.reset(self._current_taskgroup_token)
+            self._current_taskgroup_token = None
         if propagate_cancellation_error is not None:
             raise propagate_cancellation_error
 
